==> api-0.16.0-sources.jar: io/strimzi/api/kafka/model/status/StatusFluent.java <==
package io.strimzi.api.kafka.model.status;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface StatusFluent<A extends StatusFluent<A>> extends Fluent<A>{


    public A addToConditions(int index,Condition item);
    public A setToConditions(int index,Condition item);
    public A addToConditions(Condition... items);
    public A addAllToConditions(Collection<Condition> items);
    public A removeFromConditions(Condition... items);
    public A removeAllFromConditions(Collection<Condition> items);
    public A removeMatchingFromConditions(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<Condition> getConditions();
    public List<Condition> buildConditions();
    public Condition buildCondition(int index);
    public Condition buildFirstCondition();
    public Condition buildLastCondition();
    public Condition buildMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public Boolean hasMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public A withConditions(List<Condition> conditions);
    public A withConditions(Condition... conditions);
    public Boolean hasConditions();
    public StatusFluent.ConditionsNested<A> addNewCondition();
    public StatusFluent.ConditionsNested<A> addNewConditionLike(Condition item);
    public StatusFluent.ConditionsNested<A> setNewConditionLike(int index,Condition item);
    public StatusFluent.ConditionsNested<A> editCondition(int index);
    public StatusFluent.ConditionsNested<A> editFirstCondition();
    public StatusFluent.ConditionsNested<A> editLastCondition();
    public StatusFluent.ConditionsNested<A> editMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public long getObservedGeneration();
    public A withObservedGeneration(long observedGeneration);
    public Boolean hasObservedGeneration();

    public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ConditionFluent<StatusFluent.ConditionsNested<N>>{

        
    public N and();    public N endCondition();
}


}

==> api-0.21.0-sources.jar: io/strimzi/api/kafka/model/status/StatusFluent.java <==
package io.strimzi.api.kafka.model.status;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface StatusFluent<A extends StatusFluent<A>> extends Fluent<A>{


    public A addToConditions(int index,Condition item);
    public A setToConditions(int index,Condition item);
    public A addToConditions(Condition... items);
    public A addAllToConditions(Collection<Condition> items);
    public A removeFromConditions(Condition... items);
    public A removeAllFromConditions(Collection<Condition> items);
    public A removeMatchingFromConditions(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public java.util.List<Condition> getConditions();
    public java.util.List<Condition> buildConditions();
    public Condition buildCondition(int index);
    public Condition buildFirstCondition();
    public Condition buildLastCondition();
    public Condition buildMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public Boolean hasMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public A withConditions(java.util.List<Condition> conditions);
    public A withConditions(Condition... conditions);
    public Boolean hasConditions();
    public StatusFluent.ConditionsNested<A> addNewCondition();
    public StatusFluent.ConditionsNested<A> addNewConditionLike(Condition item);
    public StatusFluent.ConditionsNested<A> setNewConditionLike(int index,Condition item);
    public StatusFluent.ConditionsNested<A> editCondition(int index);
    public StatusFluent.ConditionsNested<A> editFirstCondition();
    public StatusFluent.ConditionsNested<A> editLastCondition();
    public StatusFluent.ConditionsNested<A> editMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public long getObservedGeneration();
    public A withObservedGeneration(long observedGeneration);
    public Boolean hasObservedGeneration();

    public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ConditionFluent<StatusFluent.ConditionsNested<N>>{

        
    public N and();    public N endCondition();
}


}
